@@ -32,7 +32,11 @@ extern "C" {
 WS_DLL_PUBLIC char *init_progfile_dir(const char *arg0);
 
 /*
- * Get the directory in which the program resides.
+ * Get the directory in which the main (Wireshark, TShark, Logray, etc)
+ * program resides.
+ * Extcaps should use get_extcap_dir() to get their path.
+ *
+ * @return The main program file directory.
  */
 WS_DLL_PUBLIC const char *get_progfile_dir(void);
 
@@ -146,6 +150,12 @@ WS_DLL_PUBLIC char *get_global_profiles_dir(void);
  */
 WS_DLL_PUBLIC void profile_store_persconffiles(gboolean store);
 
+/*
+ * Register a filename to the personal config files storage.
+ * This is for files which are not read using get_persconffile_path() during startup.
+ */
+WS_DLL_PUBLIC void profile_register_persconffile(const char *filename);
+
 /*
  * Check if given configuration profile exists.
  */
@@ -307,6 +317,17 @@ WS_DLL_PUBLIC gboolean files_identical(const char *fname1, const char *fname2);
  */
 WS_DLL_PUBLIC gboolean file_needs_reopen(int fd, const char* filename);
 
+/*
+ * Write content to a file in binary mode, for those operating systems that
+ * care about such things. This should be OK for all files, even text files, as
+ * we'll write the raw bytes, and we don't look at the bytes as we copy them.
+ *
+ * Returns TRUE on success, FALSE on failure. If a failure, it also
+ * displays a simple dialog window with the error message.
+ */
+WS_DLL_PUBLIC gboolean write_file_binary_mode(const char *filename,
+    const void *content, size_t content_len);
+
 /*
  * Copy a file in binary mode, for those operating systems that care about
  * such things.  This should be OK for all files, even text files, as
